#!/bin/bash

# This script is executed by Recovery component to Backup CoreTelephony   

CORETELPIDFILE=/var/run/CoreTelProviderAgent.pid
CORETELINIFILE=/var/run/CoreTelProviderAgent.ini
PROCPATH=/proc/

BackupErr_CoreTel_Restarting=3
BackupErr_General=1
BackupErr_Thread_Fail=126

echo "">>/var/log/CoreTelBRU_Script.log
echo "">>/var/log/CoreTelBRU_Script.log
echo "Starting CoreTel Backup script at...`date` ">>/var/log/CoreTelBRU_Script.log

echo "Testing whether CoreTelProvider is up or not ">>/var/log/CoreTelBRU_Script.log
# Following routine will check whether  CoreTelProviderAgent is up or not 
 
    # get CoreTelProvider pid
    if [ ! -f $CORETELPIDFILE ]; then
        echo "CoreTelProvider pid file is not existed ..exiting" >>/var/log/CoreTelBRU_Script.log
        exit $BackupErr_CoreTel_Restarting
    fi

    PID=`cat $CORETELPIDFILE`

    # get CoreTelProvider  ini
    if [ ! -f $CORETELINIFILE ]; then
          echo "CoreTelProvider ini file is not existed ..exiting">>/var/log/CoreTelBRU_Script.log
         exit $BackupErr_CoreTel_Restarting
    fi

    IPID=`cat $CORETELINIFILE`

    # two pid needs to be equal
    if [ $PID != $IPID ]; then
          echo "CoreTelProvider pid and ini values are not equal ..exiting">>/var/log/CoreTelBRU_Script.log
         exit $BackupErr_CoreTel_Restarting
    fi

    # get proc CoreTelProvider dir
    CORETELPROC=$PROCPATH$PID
    if [ ! -d $CORETELPROC ]; then
         echo "CoreTelProvider proc dir is not existed ..exiting">>/var/log/CoreTelBRU_Script.log
        exit $BackupErr_CoreTel_Restarting
    fi


echo "CoreTelProvider is up">>/var/log/CoreTelBRU_Script.log
# Now CoreTelProviderAgent is up ....Issuing backup request to CoreTelProviderAgent

echo "Issuing Backup request to CoreTelProviderAgent">>/var/log/CoreTelBRU_Script.log

/nn/sbin/CoreTelBRU_App -b
RETURN_CODE=$?
echo "Return code of previous Backup  request...$RETURN_CODE">>/var/log/CoreTelBRU_Script.log

# If CoreTelProviderAgent thread is not ready to  accept our request then we will try to restart CoreTelProviderAgent and try again

if [ $RETURN_CODE == $BackupErr_General ] || [ $RETURN_CODE == $BackupErr_Thread_Fail ]; then

    echo "Restarting CoreTelProviderAgent">>/var/log/CoreTelBRU_Script.log
    /nn/bin/processcontrol restart CoreTelProviderAgent
    if [ $? != 0 ]; then
    echo "Could not Restart CoreTelProviderAgent..exiting">>/var/log/CoreTelBRU_Script.log
    exit $BackupErr_General
    fi

    sleep 40
    echo "Issung Backup request to CoreTelProviderAgent..Second time">>/var/log/CoreTelBRU_Script.log
    /nn/sbin/CoreTelBRU_App -b
    RETURN_CODE=$?
    echo "Return code of previous Backup  request...$RETURN_CODE">>/var/log/CoreTelBRU_Script.log

fi

# currently BackupErr_Thread_Fail error is not supported by Recovery so mapped to general error
if [ $RETURN_CODE == $BackupErr_Thread_Fail ]; then
    echo "Received code is BackupErr_Thread_Fail...exiting">>/var/log/CoreTelBRU_Script.log
    exit $BackupErr_General
fi
exit $RETURN_CODE
