#!/bin/bash

# This script is executed by Recovery component to Restore CoreTelephony


CORETELPIDFILE=/var/run/CoreTelProviderAgent.pid
CORETELINIFILE=/var/run/CoreTelProviderAgent.ini
PROCPATH=/proc/

RestoreErr_CoreTel_Restarting=136
RestoreErr_General=128
RestoreErr_Thread_Fail=254 
RestoreErr_Abrt_MPE_Timer=132

echo "">>/var/log/CoreTelBRU_Script.log
echo "">>/var/log/CoreTelBRU_Script.log
echo "Starting CoreTel Restore script at...`date` ">>/var/log/CoreTelBRU_Script.log

echo "Testing whether CoreTelProvider is up or not ">>/var/log/CoreTelBRU_Script.log

# Following routine will check whether  CoreTelProviderAgent is up
 
    # get CoreTelProvider pid
    if [ ! -f $CORETELPIDFILE ]; then
        echo "CoreTelProvider pid file is not existed ..exiting" >>/var/log/CoreTelBRU_Script.log
        exit $RestoreErr_CoreTel_Restarting   
    fi

    PID=`cat $CORETELPIDFILE`

    # get CoreTelProvider ini
    if [ ! -f $CORETELINIFILE ]; then
         echo "CoreTelProvider ini file is not existed ..exiting">>/var/log/CoreTelBRU_Script.log
         exit $RestoreErr_CoreTel_Restarting
    fi

    IPID=`cat $CORETELINIFILE`

    # two pid needs to be equal
    if [ $PID != $IPID ]; then
         echo "CoreTelProvider pid and ini values are not equal ..exiting">>/var/log/CoreTelBRU_Script.log
         exit $RestoreErr_CoreTel_Restarting
    fi

    # get proc CoreTelProvider dir
    CORETELPROC=$PROCPATH$PID
    if [ ! -d $CORETELPROC ]; then
        echo "CoreTelProvider proc dir is not existed ..exiting">>/var/log/CoreTelBRU_Script.log
        exit $RestoreErr_CoreTel_Restarting
    fi

echo "CoreTelProvider is up">>/var/log/CoreTelBRU_Script.log

# Now CoreTelProviderAgent is up ..so issuing Restore request to CoreTelProviderAgent

echo "Issuing Restore request to CoreTelProviderAgent">>/var/log/CoreTelBRU_Script.log

/nn/sbin/CoreTelBRU_App -r
RETURN_CODE_FIRST=$?

echo "Return code of previous Restore  request...$RETURN_CODE_FIRST">>/var/log/CoreTelBRU_Script.log

# If CoreTelProviderAgent thread is not ready to  accept our request then we will try to restart CoreTelProviderAgent and try again

if [ $RETURN_CODE_FIRST == $RestoreErr_General ] || [ $RETURN_CODE_FIRST == $RestoreErr_Thread_Fail ]; then

    echo "Restarting CoreTelProviderAgent">>/var/log/CoreTelBRU_Script.log
    /nn/bin/processcontrol restart CoreTelProviderAgent

    if [ $? != 0 ]; then
    echo "Could not Restart CoreTelProviderAgent..exiting">>/var/log/CoreTelBRU_Script.log
    exit $RestoreErr_General
    fi

    sleep 40
    echo "Issung Restore request to CoreTelProviderAgent..Second time">>/var/log/CoreTelBRU_Script.log
    /nn/sbin/CoreTelBRU_App -r
    RETURN_CODE_FIRST=$?
    echo "Return code of previous Restore  request...$RETURN_CODE_FIRST">>/var/log/CoreTelBRU_Script.log

fi


# currently RestoreErr_Thread_Fail error is not supported by Recovery so mapped to general error
if [ $RETURN_CODE_FIRST == $RestoreErr_Thread_Fail ]; then
    echo "Received code is RestoreErr_Thread_Fail...exiting">>/var/log/CoreTelBRU_Script.log
    exit $RestoreErr_General
fi

#if error is RestoreErr_Abrt_MPE_Timer then core will not warm restart so exiting

if [ $RETURN_CODE_FIRST == $RestoreErr_Abrt_MPE_Timer ]; then
    echo "Received code is RestoreErr_Abrt_MPE_Timer...exiting">>/var/log/CoreTelBRU_Script.log
    exit $RETURN_CODE_FIRST
fi



echo "Waiting for MscService to go down .. `date`">>/var/log/CoreTelBRU_Script.log

MAXWAITLOOPS=120
loopcount=0

# Wait for up to 10 minutes for MscService to terminate, then restart it.
while [ $loopcount -lt $MAXWAITLOOPS ]; do
    sleep 5
    let loopcount+=1
    /nn/bin/processcontrol status MscService | grep Stopped
    if [ $? -eq 0 ]; then
        loopcount=$MAXWAITLOOPS
    fi
done

# starting MscService

echo "Starting MscService  .. `date`">>/var/log/CoreTelBRU_Script.log
/nn/bin/processcontrol start MscService

echo "Waiting for CoreTelProviderAgent  to come up again....`date`">>/var/log/CoreTelBRU_Script.log

# Check for pid file, ini file, and proc
# if one of them is not there, loop up to 8 minutes

CORETELPIDFILE=/var/run/CoreTelProviderAgent.pid
CORETELINIFILE=/var/run/CoreTelProviderAgent.ini

MAXCOUNT=144

#loop 12 min
count=0
while [ $count -lt $MAXCOUNT ]; do
    # get voicemail pid
    if [ ! -f $CORETELPIDFILE ]; then
        sleep 5
        let count+=1
        continue
    fi

    PID=`cat $CORETELPIDFILE`

    # get voicemail ini
    if [ ! -f $CORETELINIFILE ]; then
        sleep 5
        let count+=1
        continue
    fi

    IPID=`cat $CORETELINIFILE`

    # two pid needs to be equal
    if [ $PID != $IPID ]; then
        sleep 5
        let count+=1
        continue
    fi

    # get proc CoreTelProviderAgent dir
    CORETELPROC=$PROCPATH$PID
    if [ ! -d $CORETELPROC ]; then
        sleep 5
        let count+=1
        continue
    fi

    let count+=1

    echo "Found CoreTelProviderAgent up at `date`">>/var/log/CoreTelBRU_Script.log
    exit $RETURN_CODE_FIRST
done

echo "CoreTelProviderAgent is not up...TimeOut... `date`">>/var/log/CoreTelBRU_Script.log

exit $RETURN_CODE_FIRST

